<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>Point1P</name>
    <message>
        <location filename="../Point1P.js" line="+51"/>
        <source>Position</source>
        <translation>Umístění</translation>
    </message>
    <message>
        <location filename="../Point1PInit.js" line="+2"/>
        <source>Single &amp;Point</source>
        <translation>Samostatný &amp;Bod</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw single point</source>
        <translation>Kreslit samostatný bod</translation>
    </message>
</context>
</TS>
